pub enum AttestationError {
InvalidArgument,
GenericError,
NotSupported,
}Expand description
Error kinds returned by AttestationMgr
Variants
InvalidArgument
Some parameter or combination of parameters are recognised as invalid:
- challenge size is not allowed
- challenge object is unavailable
- token buffer is unavailable
GenericError
An error occurred that does not correspond to any defined failure cause.
NotSupported
The requested operation or a parameter is not supported by this implementation.