pub enum IsletHESError {
GenericError,
InvalidArgument,
NotPermitted,
DoesNotExist,
BadState,
NotSupported,
}Variants
GenericError
Implementations may use this error code if none of the other is applicable.
InvalidArgument
The parameters passed to the function are invalid.
NotPermitted
Measurement signer_id doesn’t match for extend operation
DoesNotExist
Slot_id of a Measurement is not populated
BadState
Slot_id of a Measurement is lock for extend operation
NotSupported
Requested key size of DAK is not supported